# Fitting a mean and standard-deviation with `abeec`
-----------------------------------------------------

The `basic_example.py` script fits a constant (`mu`) to the data stored in the `basic_data.dat` file using `abeec`.
The data was generated using the `basic_utils.gen_fake_data()` function in the `basic_utils.py` file. 
